{% extends "!layout.html" %}

{% block extrahead %}
    {{ super() }}
    <link rel="stylesheet" href="{{ pathto('_static/custom.css', 1) }}" type="text/css" />
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
{% endblock %}

{% block footer %}
    <div class="rst-footer-buttons" role="navigation" aria-label="footer navigation">
        {% if next %}
            <a href="{{ next.link|e }}" class="btn btn-neutral float-right" title="{{ next.title|striptags|e }}" accesskey="n">Next <span class="fa fa-arrow-circle-right" aria-hidden="true"></span></a>
        {% endif %}
        {% if prev %}
            <a href="{{ prev.link|e }}" class="btn btn-neutral" title="{{ prev.title|striptags|e }}" accesskey="p"><span class="fa fa-arrow-circle-left" aria-hidden="true"></span> Previous</a>
        {% endif %}
    </div>
    <hr/>
    <div role="contentinfo">
        <p>
            {%- if show_copyright %}
                {%- if hasdoc('copyright') %}
                    {% trans path=pathto('copyright'), copyright=copyright|e %}&copy; <a href="{{ path }}">Copyright</a> {{ copyright }}.{% endtrans %}
                {%- else %}
                    {% trans copyright=copyright|e %}&copy; Copyright {{ copyright }}.{% endtrans %}
                {%- endif %}
            {%- endif %}
            {%- if last_updated %}
                {% trans last_updated=last_updated|e %}Last updated on {{ last_updated }}.{% endtrans %}
            {%- endif %}
            {%- if show_sphinx %}
                {% trans sphinx_version=sphinx_version|e %}Built with <a href="https://www.sphinx-doc.org/">Sphinx</a> {{ sphinx_version }} using a <a href="https://github.com/readthedocs/sphinx_rtd_theme">theme</a> provided by <a href="https://readthedocs.org">Read the Docs</a>.{% endtrans %}
            {%- endif %}
        </p>
    </div>
{% endblock %}
